zabbix_export:
  version: '7.0'
  template_groups:
    - uuid: a571c0d144b14fd4a87a9d9b2aa9fcd6
      name: Templates/Applications
  templates:
    - uuid: 2526dce71d714e31bd545e96370c67b2
      template: 'Website by Browser'
      name: 'Website by Browser'
      description: |
        The template to monitor a website's availability and performance on the website by Browser.
        
        Zabbix server uses a web browser to perform navigation and collect performance metrics.
        
        Generated by official Zabbix template tool "Templator"
      vendor:
        name: Zabbix
        version: 7.0-0
      groups:
        - name: Templates/Applications
      items:
        - uuid: b5d5b396dfdc4fc99e4c2d0216728027
          name: 'Website {$WEBSITE.DOMAIN} Get data'
          type: BROWSER
          key: website.get.data
          delay: '{$WEBSITE.GET.DATA.INTERVAL}'
          history: '0'
          value_type: TEXT
          params: |
            const Website = {
                params: {},
            
                setParams(params) {
                    ['scheme', 'domain','width', 'height'].forEach(function (field) {
                        if (typeof params !== 'object' || !params[field]) {
                            throw new Error('Required param is not set: ' + field + '.');
                        }
                    });
                    this.params = params;
                },
            
                getOptions(browser) {
                    switch ((browser || '').trim().toLowerCase()) {
                        case 'firefox':
                            return Browser.firefoxOptions();
                        case 'safari':
                            return Browser.safariOptions();
                        case 'edge':
                            return Browser.edgeOptions();
                        default:
                            return Browser.chromeOptions();
                    }
                },
            
                getPerformance() {
                    const browser = new Browser(Website.getOptions(Website.params.browser));
                    const url = Website.params.scheme + '://' + Website.params.domain + '/' + Website.params.path
                    const screenshot = '';
                    browser.setScreenSize(Number(Website.params.width), Number(Website.params.height))
                    browser.navigate(url);
                    browser.collectPerfEntries();
                    screenshot = browser.getScreenshot();
                    const result = browser.getResult();
                    result.screenshot = screenshot;
            
                    return JSON.stringify(result);
                }
            };
            
            try {
                Website.setParams(JSON.parse(value));
                return Website.getPerformance();
            
            } catch (error) {
                error += (String(error).endsWith('.')) ? '' : '.';
                Zabbix.log(3, '[ Website get metrics] ERROR: ' + error);
                return JSON.stringify({ 'error': error });
            }
          description: 'Returns the JSON with performance counters of the requested website.'
          preprocessing:
            - type: CHECK_NOT_SUPPORTED
              parameters:
                - '-1'
          parameters:
            - name: browser
              value: '{$WEBSITE.BROWSER}'
            - name: domain
              value: '{$WEBSITE.DOMAIN}'
            - name: height
              value: '{$WEBSITE.SCREEN.HEIGHT}'
            - name: path
              value: '{$WEBSITE.PATH}'
            - name: scheme
              value: '{$WEBSITE.SCHEME}'
            - name: width
              value: '{$WEBSITE.SCREEN.WIDTH}'
          tags:
            - tag: component
              value: raw
        - uuid: 0de3b06fb406427499b0d4831774b540
          name: 'Get metrics check'
          type: DEPENDENT
          key: website.metrics.check
          value_type: CHAR
          description: 'Check that the performance counters of the requested website data has been received correctly.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.error
              error_handler: CUSTOM_VALUE
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: status
          triggers:
            - uuid: 56970ddca5b94afdb2186741edd85362
              expression: 'length(last(/Website by Browser/website.metrics.check))>0'
              name: 'Failed to get metrics data'
              event_name: 'Failed to get JSON of the requested website ''{$WEBSITE.DOMAIN}'''
              opdata: 'Current value: {ITEM.LASTVALUE1}'
              priority: HIGH
              description: 'Failed to get JSON with performance counters of the requested website ''{$WEBSITE.DOMAIN}''.'
              tags:
                - tag: scope
                  value: availability
        - uuid: d96d4723a8e34393bf4e3e2973eafc48
          name: 'Website {$WEBSITE.DOMAIN} Navigation DNS lookup time'
          type: DEPENDENT
          key: website.navigation.dns_lookup_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spent on DNS lookup (domainLookupEnd - domainLookupStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.dns_lookup_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: 760e0d852a924648a8f75bb24b888445
          name: 'Website {$WEBSITE.DOMAIN} Navigation domContentLoaded time'
          type: DEPENDENT
          key: website.navigation.dom_content_loaded_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spent on DOM content loading (domContentLoadedEventEnd - domContentLoadedEventStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.dom_content_loading_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: 6056b72c640a4560b90ee49df1e66171
          name: 'Website {$WEBSITE.DOMAIN} Navigation encodedBody size'
          type: DEPENDENT
          key: website.navigation.encoded_size
          value_type: FLOAT
          trends: '0'
          units: B
          description: 'Measuring of encoded size (encodedBodySize).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.encoded_size
              error_handler: DISCARD_VALUE
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: cc0e03d92cb34298a952b06f7185efd6
          name: 'Website {$WEBSITE.DOMAIN} Navigation load event time'
          type: DEPENDENT
          key: website.navigation.load_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of load finished time (loadEventEnd).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.load_finished
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
          triggers:
            - uuid: a2d63bfe681848fdb984f3b579262086
              expression: 'last(/Website by Browser/website.navigation.load_time)>{$WEBSITE.NAVIGATION.LOAD.MAX.WARN}'
              name: 'Website navigation load event time is too slow'
              event_name: 'Website {$WEBSITE.DOMAIN} navigation load event time > {$WEBSITE.NAVIGATION.LOAD.MAX.WARN}'
              opdata: 'Current value: {ITEM.LASTVALUE1}'
              priority: WARNING
              dependencies:
                - name: 'Failed to get metrics data'
                  expression: 'length(last(/Website by Browser/website.metrics.check))>0'
              tags:
                - tag: scope
                  value: notice
        - uuid: 12d8df72ebfc493d90f4b47773e4101e
          name: 'Website {$WEBSITE.DOMAIN} Navigation request time'
          type: DEPENDENT
          key: website.navigation.request_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spend on the request (responseStart - requestStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.request_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: 326c2f6a5d0340418a7d2f4416477fd4
          name: 'Website {$WEBSITE.DOMAIN} Navigation resource fetch time'
          type: DEPENDENT
          key: website.navigation.resource_fetch_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spent to fetch the resource (without redirects) (responseEnd - fetchStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.resource_fetch_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: 37d268e1ba1c42e98eeb1717e92d7c17
          name: 'Website {$WEBSITE.DOMAIN} Navigation response time'
          type: DEPENDENT
          key: website.navigation.response_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spend on the response (responseEnd - responseStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.response_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: 35487bbb10ab47fe9d210cf1d4c0695d
          name: 'Website {$WEBSITE.DOMAIN} Navigation service worker processing time'
          type: DEPENDENT
          key: website.navigation.service_worker_processing_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of sum of time spend on browser''s service worker processing (fetchStart - workerStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.service_worker_processing_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: 5adf88f1c63145bfb544a6e590b1b8ce
          name: 'Website {$WEBSITE.DOMAIN} Navigation TCP handshake time'
          type: DEPENDENT
          key: website.navigation.tcp_handshake_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spent on TCP handshake (connectEnd - connectStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.tcp_handshake_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: 34663a973a5d4b22a841d6a751dbe09c
          name: 'Website {$WEBSITE.DOMAIN} Navigation TLS negotiation time'
          type: DEPENDENT
          key: website.navigation.tls_negotiation_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spent on TLS negotiation (requestStart - secureConnectionStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.tls_negotiation_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: ae62ce5db2054f40ac7e281437d38f53
          name: 'Website {$WEBSITE.DOMAIN} Navigation decodedBody size'
          type: DEPENDENT
          key: website.navigation.total_size
          value_type: FLOAT
          trends: '0'
          units: B
          description: 'Measuring of total size (decodedBodySize).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.total_size
              error_handler: DISCARD_VALUE
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: 7c1d1abd30b445d69f3b73ff4a1ba356
          name: 'Website {$WEBSITE.DOMAIN} Navigation transfer size'
          type: DEPENDENT
          key: website.navigation.transferred_size
          value_type: FLOAT
          trends: '0'
          units: B
          description: 'Measuring of transferred size (transferSize).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.navigation.transferred_size
              error_handler: DISCARD_VALUE
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: navigation
        - uuid: 3557ae18d19e49839fb3012e79949b49
          name: 'Website {$WEBSITE.DOMAIN} Resource DNS lookup time'
          type: DEPENDENT
          key: website.resource.dns_lookup_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spent on DNS lookup (domainLookupEnd - domainLookupStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.dns_lookup_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: 6e29d13df9d94b22b84c3522ea451917
          name: 'Website {$WEBSITE.DOMAIN} Resource domContentLoaded time'
          type: DEPENDENT
          key: website.resource.dom_content_loaded_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spent on DOM content loading (domContentLoadedEventEnd - domContentLoadedEventStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.dom_content_loading_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: 09a5ead05ce64371aa731cf566b9b0f9
          name: 'Website {$WEBSITE.DOMAIN} Resource encodedBody size'
          type: DEPENDENT
          key: website.resource.encoded_size
          value_type: FLOAT
          trends: '0'
          units: B
          description: 'Measuring of encoded size (encodedBodySize).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.encoded_size
              error_handler: DISCARD_VALUE
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: 8e051253fc8c46aa9da009cb022d9023
          name: 'Website {$WEBSITE.DOMAIN} Resource fetch time'
          type: DEPENDENT
          key: website.resource.fetch_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spent to fetch the resource (without redirects) (responseEnd - fetchStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.resource_fetch_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: fa84484786754da7b68a9ec3c50d63c4
          name: 'Website {$WEBSITE.DOMAIN} Resource load event time'
          type: DEPENDENT
          key: website.resource.load_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of load finished time (loadEventEnd).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.load_finished
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
          triggers:
            - uuid: 1f7fbe56f5bf49468fb597a2ff986cd7
              expression: 'last(/Website by Browser/website.resource.load_time)>{$WEBSITE.RESOURCE.LOAD.MAX.WARN}'
              name: 'Website resource load event time is too slow'
              event_name: 'Website {$WEBSITE.DOMAIN} resource load event time > ''{$WEBSITE.RESOURCE.LOAD.MAX.WARN}'''
              opdata: 'Current value: {ITEM.LASTVALUE1}'
              priority: WARNING
              dependencies:
                - name: 'Failed to get metrics data'
                  expression: 'length(last(/Website by Browser/website.metrics.check))>0'
              tags:
                - tag: scope
                  value: notice
        - uuid: a53c136efe8141028f09cc1ca8277c10
          name: 'Website {$WEBSITE.DOMAIN} Resource request time'
          type: DEPENDENT
          key: website.resource.request_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spend on the request (responseStart - requestStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.request_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: f99d69f39c404d5a94cf00a96a3f0701
          name: 'Website {$WEBSITE.DOMAIN} Resource response time'
          type: DEPENDENT
          key: website.resource.response_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spend on the response (responseEnd - responseStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.response_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: b2199d4d0cc146aeb268e41fe65ca7ac
          name: 'Website {$WEBSITE.DOMAIN} Resource service worker processing time'
          type: DEPENDENT
          key: website.resource.service_worker_processing_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of sum of time spend on browser''s service worker processing (fetchStart - workerStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.service_worker_processing_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: 5b57473fffbf45d5bc3ca33e903e0b35
          name: 'Website {$WEBSITE.DOMAIN} Resource TCP handshake time'
          type: DEPENDENT
          key: website.resource.tcp_handshake_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spent on TCP handshake (connectEnd - connectStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.tcp_handshake_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: 61071f340c6b47f2ac05fbd15e393dd3
          name: 'Website {$WEBSITE.DOMAIN} Resource TLS negotiation time'
          type: DEPENDENT
          key: website.resource.tls_negotiation_time
          value_type: FLOAT
          trends: '0'
          units: s
          description: 'Measuring of time spent on TLS negotiation (requestStart - secureConnectionStart).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.tls_negotiation_time
              error_handler: DISCARD_VALUE
            - type: MULTIPLIER
              parameters:
                - '0.001'
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: 479d7c890adf46ac88e11a146f193f56
          name: 'Website {$WEBSITE.DOMAIN} Resource decodedBody size'
          type: DEPENDENT
          key: website.resource.total_size
          value_type: FLOAT
          trends: '0'
          units: B
          description: 'Measuring of total size (decodedBodySize).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.total_size
              error_handler: DISCARD_VALUE
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: 6b98ca6df6894be29b4ab7c645cac92d
          name: 'Website {$WEBSITE.DOMAIN} Resource transfer size'
          type: DEPENDENT
          key: website.resource.transferred_size
          value_type: FLOAT
          trends: '0'
          units: B
          description: 'Measuring of transferred size (transferSize).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.performance_data.summary.resource.transferred_size
              error_handler: DISCARD_VALUE
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
            - tag: performance
              value: resource
        - uuid: 931d98f67f9f45069711558083f40d33
          name: 'Website {$WEBSITE.DOMAIN} Screenshot'
          type: DEPENDENT
          key: website.screenshot
          value_type: BINARY
          description: 'Website {$WEBSITE.DOMAIN} screenshot.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.screenshot
              error_handler: DISCARD_VALUE
          master_item:
            key: website.get.data
          tags:
            - tag: component
              value: application
      tags:
        - tag: class
          value: application
        - tag: target
          value: browser
      macros:
        - macro: '{$WEBSITE.BROWSER}'
          value: chrome
          description: 'Browser to be used for data collection.'
        - macro: '{$WEBSITE.DOMAIN}'
          value: www.example.com
          description: 'The domain name.'
        - macro: '{$WEBSITE.GET.DATA.INTERVAL}'
          value: 0s;m/15
          description: 'Update interval for get raw data item.'
        - macro: '{$WEBSITE.NAVIGATION.LOAD.MAX.WARN}'
          value: '5'
          description: 'The maximum browser response time expressed in seconds for a trigger expression.'
        - macro: '{$WEBSITE.PATH}'
          description: 'The path to resource.'
        - macro: '{$WEBSITE.RESOURCE.LOAD.MAX.WARN}'
          value: '5'
          description: 'The maximum browser response time expressed in seconds for a trigger expression.'
        - macro: '{$WEBSITE.SCHEME}'
          value: https
          description: 'The request scheme, which may be either HTTP or HTTPS.'
        - macro: '{$WEBSITE.SCREEN.HEIGHT}'
          value: '1080'
          description: 'Screen size height in pixels, used for screenshot.'
        - macro: '{$WEBSITE.SCREEN.WIDTH}'
          value: '1920'
          description: 'Screen size width in pixels, used for screenshot.'
      dashboards:
        - uuid: 5afcfa0ecebd40d9a8fe16491ea7615e
          name: 'Website overview'
          pages:
            - name: Screenshots
              widgets:
                - type: itemhistory
                  name: Screenshots
                  width: '16'
                  height: '10'
                  hide_header: 'YES'
                  fields:
                    - type: ITEM
                      name: columns.0.itemid
                      value:
                        host: 'Website by Browser'
                        key: website.screenshot
                    - type: STRING
                      name: columns.0.name
                      value: Screenshot
                    - type: INTEGER
                      name: columns.0.show_thumbnail
                      value: '1'
                    - type: INTEGER
                      name: layout
                      value: '1'
                    - type: STRING
                      name: reference
                      value: MBTYI
                    - type: INTEGER
                      name: show_timestamp
                      value: '1'
                - type: svggraph
                  name: 'Load time'
                  x: '16'
                  width: '28'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: ds.0.fill
                      value: '4'
                    - type: STRING
                      name: ds.0.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Navigation load event time'
                    - type: INTEGER
                      name: ds.0.width
                      value: '2'
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color
                      value: FFD54F
                    - type: INTEGER
                      name: ds.1.fill
                      value: '4'
                    - type: STRING
                      name: ds.1.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Resource load event time'
                    - type: INTEGER
                      name: ds.1.missingdatafunc
                      value: '1'
                    - type: INTEGER
                      name: ds.1.width
                      value: '2'
                    - type: STRING
                      name: reference
                      value: OVVDR
                    - type: INTEGER
                      name: severities.0
                      value: '2'
                    - type: INTEGER
                      name: severities.1
                      value: '3'
                    - type: INTEGER
                      name: severities.2
                      value: '4'
                    - type: INTEGER
                      name: severities.3
                      value: '5'
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Navigation timing'
                  x: '16'
                  'y': '5'
                  width: '28'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color
                      value: FF7043
                    - type: STRING
                      name: ds.0.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Navigation resource fetch time'
                    - type: STRING
                      name: ds.1.color
                      value: FFD54F
                    - type: STRING
                      name: ds.1.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Navigation DNS lookup time'
                    - type: STRING
                      name: ds.2.color
                      value: 546E7A
                    - type: STRING
                      name: ds.2.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Navigation TCP handshake time'
                    - type: STRING
                      name: ds.3.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Navigation TLS negotiation time'
                    - type: STRING
                      name: ds.4.color
                      value: 3949AB
                    - type: STRING
                      name: ds.4.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Navigation request time'
                    - type: STRING
                      name: ds.5.color
                      value: 388E3C
                    - type: STRING
                      name: ds.5.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Navigation response time'
                    - type: STRING
                      name: reference
                      value: FBLXC
                - type: svggraph
                  name: 'Navigation size'
                  x: '44'
                  width: '28'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color
                      value: '666699'
                    - type: STRING
                      name: ds.0.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Navigation decodedBody size'
                    - type: INTEGER
                      name: ds.0.type
                      value: '3'
                    - type: STRING
                      name: ds.1.color
                      value: FFD54F
                    - type: STRING
                      name: ds.1.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Navigation encodedBody size'
                    - type: INTEGER
                      name: ds.1.type
                      value: '3'
                    - type: STRING
                      name: ds.2.color
                      value: 0EC9AC
                    - type: STRING
                      name: ds.2.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Navigation transfer size'
                    - type: INTEGER
                      name: ds.2.type
                      value: '3'
                    - type: STRING
                      name: reference
                      value: PXXYQ
                    - type: INTEGER
                      name: severities.0
                      value: '2'
                    - type: INTEGER
                      name: severities.1
                      value: '3'
                    - type: INTEGER
                      name: severities.2
                      value: '4'
                    - type: INTEGER
                      name: severities.3
                      value: '5'
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Resource timing'
                  x: '44'
                  'y': '5'
                  width: '28'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color
                      value: FF8000
                    - type: STRING
                      name: ds.0.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Resource resource fetch time'
                    - type: STRING
                      name: ds.1.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Resource DNS lookup time'
                    - type: STRING
                      name: ds.2.color
                      value: FFD54F
                    - type: STRING
                      name: ds.2.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Resource TCP handshake time'
                    - type: STRING
                      name: ds.3.color
                      value: 0EC9AC
                    - type: STRING
                      name: ds.3.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Resource TLS negotiation time'
                    - type: STRING
                      name: ds.4.color
                      value: 524BBC
                    - type: STRING
                      name: ds.4.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Resource request time'
                    - type: STRING
                      name: ds.5.color
                      value: ED1248
                    - type: STRING
                      name: ds.5.items.0
                      value: 'Website {$WEBSITE.DOMAIN} Resource response time'
                    - type: STRING
                      name: reference
                      value: ZLUHM
  graphs:
    - uuid: c373d777570a42fda3cea03d24bed67f
      name: 'Performance Navigation Timing'
      graph_items:
        - color: 199C0D
          item:
            host: 'Website by Browser'
            key: website.navigation.dns_lookup_time
        - sortorder: '1'
          color: F63100
          item:
            host: 'Website by Browser'
            key: website.navigation.tcp_handshake_time
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Website by Browser'
            key: website.navigation.tls_negotiation_time
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Website by Browser'
            key: website.navigation.dom_content_loaded_time
        - sortorder: '4'
          color: FC6EA3
          item:
            host: 'Website by Browser'
            key: website.navigation.resource_fetch_time
        - sortorder: '5'
          color: 6C59DC
          item:
            host: 'Website by Browser'
            key: website.navigation.service_worker_processing_time
        - sortorder: '6'
          color: C7A72D
          item:
            host: 'Website by Browser'
            key: website.navigation.request_time
        - sortorder: '7'
          color: BA2A5D
          item:
            host: 'Website by Browser'
            key: website.navigation.response_time
    - uuid: 3301237b56ea455b8e1344bb467d11b0
      name: 'Performance Resource Timing'
      graph_items:
        - color: 199C0D
          item:
            host: 'Website by Browser'
            key: website.resource.dns_lookup_time
        - sortorder: '1'
          color: F63100
          item:
            host: 'Website by Browser'
            key: website.resource.tcp_handshake_time
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Website by Browser'
            key: website.resource.tls_negotiation_time
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Website by Browser'
            key: website.resource.dom_content_loaded_time
        - sortorder: '4'
          color: FC6EA3
          item:
            host: 'Website by Browser'
            key: website.resource.fetch_time
        - sortorder: '5'
          color: 6C59DC
          item:
            host: 'Website by Browser'
            key: website.resource.service_worker_processing_time
        - sortorder: '6'
          color: C7A72D
          item:
            host: 'Website by Browser'
            key: website.resource.request_time
        - sortorder: '7'
          color: BA2A5D
          item:
            host: 'Website by Browser'
            key: website.resource.response_time
